@@ -11,10 +11,17 @@ end
 module RSpec
   module Core
     class ExampleGroup
+      def clear_memoized
+        if respond_to? :__init_memoized, true
+          __init_memoized
+        else
+          @__memoized = nil
+        end
+      end
+
       def clear_lets
-        @__memoized = {}
+        clear_memoized
       end
     end
   end
 end
-
